// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.ads.searchads360.v0.resources;

import "google/ads/searchads360/v0/enums/asset_set_link_status.proto";
import "google/api/field_behavior.proto";
import "google/api/resource.proto";

option csharp_namespace = "Google.Ads.SearchAds360.V0.Resources";
option go_package = "google.golang.org/genproto/googleapis/ads/searchads360/v0/resources;resources";
option java_multiple_files = true;
option java_outer_classname = "CampaignAssetSetProto";
option java_package = "com.google.ads.searchads360.v0.resources";
option objc_class_prefix = "GASA360";
option php_namespace = "Google\\Ads\\SearchAds360\\V0\\Resources";
option ruby_package = "Google::Ads::SearchAds360::V0::Resources";

// Proto file describing the CampaignAsset resource.

// CampaignAssetSet is the linkage between a campaign and an asset set.
// Adding a CampaignAssetSet links an asset set with a campaign.
message CampaignAssetSet {
  option (google.api.resource) = {
    type: "searchads360.googleapis.com/CampaignAssetSet"
    pattern: "customers/{customer_id}/campaignAssetSets/{campaign_id}~{asset_set_id}"
  };

  // Immutable. The resource name of the campaign asset set.
  // Asset set asset resource names have the form:
  //
  // `customers/{customer_id}/campaignAssetSets/{campaign_id}~{asset_set_id}`
  string resource_name = 1 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "searchads360.googleapis.com/CampaignAssetSet"
    }
  ];

  // Immutable. The campaign to which this asset set is linked.
  string campaign = 2 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "searchads360.googleapis.com/Campaign"
    }
  ];

  // Immutable. The asset set which is linked to the campaign.
  string asset_set = 3 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "searchads360.googleapis.com/AssetSet"
    }
  ];

  // Output only. The status of the campaign asset set asset. Read-only.
  google.ads.searchads360.v0.enums.AssetSetLinkStatusEnum.AssetSetLinkStatus
      status = 4 [(google.api.field_behavior) = OUTPUT_ONLY];
}
